@@ -89,7 +89,7 @@ class TestAlarmProcessor(unittest.TestCase):
         """Should cause the alarm_ttl to fire log a warning and push to finished queue."""
         alarm_dict = {"tenantId": "0", "alarmDefinitionId": "0", "alarmId": "1", "alarmName": "test Alarm",
                       "oldState": "OK", "newState": "ALARM", "stateChangeReason": "I am alarming!",
-                      "timestamp": 1375346830, "actionsEnabled": 1}
+                      "timestamp": 1375346830, "actionsEnabled": 1, "metrics": "cpu_util"}
         self.alarm_queue.put(self._create_raw_alarm(0, 2, alarm_dict))
         finished, log_msg = self._run_alarm_processor(self.finished_queue, None)
 
@@ -101,7 +101,7 @@ class TestAlarmProcessor(unittest.TestCase):
         """
         alarm_dict = {"tenantId": "0", "alarmDefinitionId": "0", "alarmId": "1", "alarmName": "test Alarm",
                       "oldState": "OK", "newState": "ALARM", "stateChangeReason": "I am alarming!",
-                      "timestamp": time.time(), "actionsEnabled": 1}
+                      "timestamp": time.time(), "actionsEnabled": 1, "metrics": "cpu_util"}
         self.alarm_queue.put(self._create_raw_alarm(0, 3, alarm_dict))
         finished, log_msg = self._run_alarm_processor(self.finished_queue, None)
 
@@ -112,7 +112,7 @@ class TestAlarmProcessor(unittest.TestCase):
         """
         alarm_dict = {"tenantId": "0", "alarmDefinitionId": "0", "alarmId": "1", "alarmName": "test Alarm",
                       "oldState": "OK", "newState": "ALARM", "stateChangeReason": "I am alarming!",
-                      "timestamp": time.time(), "actionsEnabled": 1}
+                      "timestamp": time.time(), "actionsEnabled": 1, "metrics": "cpu_util"}
         self.alarm_queue.put(self._create_raw_alarm(0, 4, alarm_dict))
         sql_response = [['test notification', 'EMAIL', 'me@here.com']]
         finished, log_msg = self._run_alarm_processor(self.notification_queue, sql_response)
@@ -124,7 +124,7 @@ class TestAlarmProcessor(unittest.TestCase):
     def test_two_valid_notifications(self):
         alarm_dict = {"tenantId": "0", "alarmDefinitionId": "0", "alarmId": "1", "alarmName": "test Alarm",
                       "oldState": "OK", "newState": "ALARM", "stateChangeReason": "I am alarming!",
-                      "timestamp": time.time(), "actionsEnabled": 1}
+                      "timestamp": time.time(), "actionsEnabled": 1, "metrics": "cpu_util"}
         self.alarm_queue.put(self._create_raw_alarm(0, 5, alarm_dict))
         sql_response = [['test notification', 'EMAIL', 'me@here.com'], ['test notification2', 'EMAIL', 'me@here.com']]
         finished, log_msg = self._run_alarm_processor(self.notification_queue, sql_response)
